//
//  kmpg
//
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef PREFS_H
#define PREFS_H

#include <qlabel.h>
#include <qpushbt.h>
#include <qbttngrp.h>
#include <qradiobt.h>
#include <qchkbox.h>
#include <qlined.h>
#include <qtabdlg.h>

#include <kconfig.h>
#include <kapp.h>
#include <kslider.h>

class Preferences : public QTabDialog
{
      Q_OBJECT
   public:
      Preferences( QWidget* parent=0 );
      ~Preferences();
      void applyPrefs();
      QString getHttpProxy() { return _httpProxy.copy(); };
      int getHttpPort() { return _httpPort; };
      bool getPlayOnOpen() { return _playOnOpen; };
      bool getReadID3() { return _readID3; };
      bool getAutoscroll() { return _autoscroll; };
      bool getForceToMono() { return _forceToMono; };
      bool getResync() { return _Resync; };
      int getMonoMode() { return _monoMode; };
      int getDownsample() { return _downsample; };
      bool getCheckRangeViolations() { return _checkRangeViolations; };
      bool getChangeScalefactor() { return _changeScalefactor; };
      int getScalefactor() { return _scalefactor; };
      bool getUseDefaultAudioDevice() { return _useDefaultAudioDevice; };
      QString getAudioDevice() { return _audioDevice.copy(); };
      int getOutputTo() { return _outputTo; };
      int getBufferSize() { return _bufferSize; };
   protected:
      void initPrefs();
      void createPage1();
      void createPage2();
      void createPage3();
   signals:
      void sigChanged(); // The preferences have changed
   public slots:
      void slotShow();
      void slotOk();
      void slotApply();
      void slotCancel();
      void slotChange();  // Called whenever a setting is changed
      void slotChange(int); // Alternative, used by Kslider
      void slotChange( const char* );
   private:
      // pages
      QWidget *page1, *page2, *page3;
      
      // page 1
      QLineEdit *leHttpProxy, *leHttpProxyPort;
      QCheckBox *cbPlayOnOpen, *cbReadID3, *cbAutoscroll;

      // page 2
      QRadioButton *rbMono, *rbMonoLeft, *rbMonoRight, *rbMonoMix, *rbStereo, *rbDS1, *rbDS2, *rbDS3;
      QButtonGroup *buttonGroup;
      QCheckBox *cbRangeViolation, *cbScalefactor, *cbResync;
      QLineEdit *leScalefactor;
      
      // page 3
      QRadioButton *rbDeviceDefault, *rbDeviceOther, *rbSpeaker, *rbLineout, *rbHeadphones;
      QLineEdit *leDevice;
      KSlider *slider;

      int rbHeight;
      bool prefsChanged;

      // The current configuration
      // Page 1
      QString _httpProxy;
      int _httpPort;
      bool _playOnOpen;
      bool _readID3;
      bool _autoscroll;
      
      // Page 2
      bool _forceToMono;
      int _monoMode; // 1=left, 2=right, 3=mix
      int _downsample; // 1=none, 2=1:2, 3=1:4
      bool _checkRangeViolations;
      bool _changeScalefactor;
      bool _Resync;
      int _scalefactor;

      // Page 3
      bool _useDefaultAudioDevice;
      QString _audioDevice;
      int _outputTo; // 1=speaker, 2=lineout, 3=headphones
      int _bufferSize;
};

#endif

